Documentation
¶
Index ¶
- Variables
- func FormDataBodyValidate(w http.ResponseWriter, r *http.Request, structData any) error
- func GetTranslation(lang string) ut.Translator
- func JSONBodyReadAndValidate(w http.ResponseWriter, r *http.Request, structData any) error
- func URLParamsValidate(ctx context.Context, w http.ResponseWriter, structData any) error
- func ValidateDNS1035Label(fl validator.FieldLevel) bool
- func ValidateDNS1123Label(fl validator.FieldLevel) bool
- func ValidateDNS1123Subdomain(fl validator.FieldLevel) bool
- func ValidateKubeconfig(fl validator.FieldLevel) bool
Constants ¶
This section is empty.
Variables ¶
var (
Validate *validator.Validate
)
Functions ¶
func FormDataBodyValidate ¶
func GetTranslation ¶
func GetTranslation(lang string) ut.Translator
func JSONBodyReadAndValidate ¶
func URLParamsValidate ¶
func ValidateDNS1035Label ¶
func ValidateDNS1035Label(fl validator.FieldLevel) bool
ValidateDNS1035Label validates RFC 1035 DNS label names Used by some specific Kubernetes resources
func ValidateDNS1123Label ¶
func ValidateDNS1123Label(fl validator.FieldLevel) bool
ValidateDNS1123Label validates RFC 1123 DNS label names Used by container names, port names, etc.
func ValidateDNS1123Subdomain ¶
func ValidateDNS1123Subdomain(fl validator.FieldLevel) bool
ValidateDNS1123Subdomain validates RFC 1123 DNS subdomain names Used by most Kubernetes resources
func ValidateKubeconfig ¶
func ValidateKubeconfig(fl validator.FieldLevel) bool
ValidateKubeconfig validates that a string contains a valid kubeconfig YAML with required clusters, contexts, and users sections.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.